GpuBackendType enum

Which native graphics API an adapter runs on. Raw value = index.

Inheritance
Available extensions

Values

undefined → const GpuBackendType
nullBackend → const GpuBackendType
webgpu → const GpuBackendType
d3d11 → const GpuBackendType
d3d12 → const GpuBackendType
metal → const GpuBackendType
vulkan → const GpuBackendType
openGL → const GpuBackendType
openGLES → const GpuBackendType

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromRaw(int raw) GpuBackendType

Constants

values → const List<GpuBackendType>
A constant List of the values in this enum, in order of their declaration.