GpuInputAxis class

A two-sided axis: reads -1 while negative is active, +1 for positive, 0 for neither or both.

Constructors

GpuInputAxis({required GpuInputBinding negative, required GpuInputBinding positive})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
negative GpuInputBinding
final
positive GpuInputBinding
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited