GpuLayoutEntry class

Constructors

GpuLayoutEntry({required int binding, required int visibility, required GpuBindingType type, GpuTextureViewDimension viewDimension = GpuTextureViewDimension.d2, bool hasDynamicOffset = false, GpuTextureSampleType sampleType = GpuTextureSampleType.float, bool multisampled = false, GpuSamplerBindingType samplerType = GpuSamplerBindingType.filtering})
const

Properties

binding int
final
hasDynamicOffset bool
For buffer types: bind with dynamic offsets via setBindGroup.
final
hashCode int
The hash code for this object.
no setterinherited
multisampled bool
For GpuBindingType.texture: bind texture_multisampled_2d.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
samplerType GpuSamplerBindingType
For GpuBindingType.sampler: use GpuSamplerBindingType.comparison for sampler_comparison (shadow mapping).
final
sampleType GpuTextureSampleType
For GpuBindingType.texture: how shaders sample it (use GpuTextureSampleType.depth for texture_depth_2d).
final
type GpuBindingType
final
viewDimension GpuTextureViewDimension
For GpuBindingType.texture: the view dimensionality shaders expect.
final
visibility int
Bitmask of GpuShaderStage values.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited