GpuStencilOperation enum
Stencil operations (raw WGPUStencilOperation).
Values
- keep → const GpuStencilOperation
-
const GpuStencilOperation(1) - zero → const GpuStencilOperation
-
const GpuStencilOperation(2) - replace → const GpuStencilOperation
-
const GpuStencilOperation(3) - invert → const GpuStencilOperation
-
const GpuStencilOperation(4) - incrementClamp → const GpuStencilOperation
-
const GpuStencilOperation(5) - decrementClamp → const GpuStencilOperation
-
const GpuStencilOperation(6) - incrementWrap → const GpuStencilOperation
-
const GpuStencilOperation(7) - decrementWrap → const GpuStencilOperation
-
const GpuStencilOperation(8)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - raw → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
GpuStencilOperation> - A constant List of the values in this enum, in order of their declaration.