GpuBlendMode enum
Color blend presets for render pipelines. Raw value = index.
Values
- none → const GpuBlendMode
-
Opaque — no blending.
- alpha → const GpuBlendMode
-
Classic alpha:
src.rgb·a + dst.rgb·(1−a). - additive → const GpuBlendMode
-
Additive:
src + dst. - premultiplied → const GpuBlendMode
-
Premultiplied alpha:
src + dst·(1−a).
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
GpuBlendMode> - A constant List of the values in this enum, in order of their declaration.