GpuVertexLayout class
The layout of one vertex buffer slot.
Constructors
-
GpuVertexLayout({required int arrayStride, GpuVertexStepMode stepMode = GpuVertexStepMode.vertex, required List<
GpuVertexAttr> attributes}) -
const
Properties
- arrayStride → int
-
final
-
attributes
→ List<
GpuVertexAttr> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stepMode → GpuVertexStepMode
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited